#
# spec file for package gtkd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gtkd_major  3
%define gtkd_minor  9
%define gtkd_bugfix 0
%define sover  0
Name:           gtkd
Version:        3.9.0
Release:        3.5
Summary:        D binding and OO wrapper for GTK+
License:        LGPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://gtkd.org/
Source:         https://github.com/gtkd-developers/GtkD/archive/v%{version}/gtkd-%{version}.tar.gz
Patch1:         fix-build.patch
BuildRequires:  ldc
BuildRequires:  ldc-phobos-devel
BuildRequires:  pkgconfig
Requires:       Mesa-libGL1
Requires:       atk
Requires:       cairo
Requires:       gstreamer
Requires:       gstreamer-plugins-base
Requires:       gtk3
Requires:       gtksourceview
Requires:       libGLU1
Requires:       libcurl
Requires:       libgstreamerd-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkd-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkdgl-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkdsv-%{gtkd_major}-%{sover} = %{version}
Requires:       libpeas
Requires:       libpeas-gtk
Requires:       libpeasd-%{gtkd_major}-%{sover} = %{version}
Requires:       libvted-%{gtkd_major}-%{sover} = %{version}
Requires:       pango
Requires:       vte

%description
GTK+ is a highly usable, feature rich toolkit for creating graphical user
interfaces which boasts cross platform compatibility and an easy to use API.

%package     -n libgstreamerd-%{gtkd_major}-%{sover}
Summary:        GtkD gstreamerd library
Group:          System/Libraries

%description -n libgstreamerd-%{gtkd_major}-%{sover}
This package contains the GtkD gstreamerd library.

%package     -n libgtkd-%{gtkd_major}-%{sover}
Summary:        GtkD base library
Group:          System/Libraries

%description -n libgtkd-%{gtkd_major}-%{sover}
This package contains the GtkD base library.

%package     -n libgtkdgl-%{gtkd_major}-%{sover}
Summary:        GtkD gtkdgl library
Group:          System/Libraries

%description -n libgtkdgl-%{gtkd_major}-%{sover}
This package contains the GtkDGL library.

%package     -n libgtkdsv-%{gtkd_major}-%{sover}
Summary:        GtkD sourceview library
Group:          System/Libraries

%description -n libgtkdsv-%{gtkd_major}-%{sover}
This package contains the GtkD sourceview library.

%package     -n libpeasd-%{gtkd_major}-%{sover}
Summary:        GtkD peasd library
Group:          System/Libraries

%description -n libpeasd-%{gtkd_major}-%{sover}
This package contains the GtkD peasd library.

%package     -n libvted-%{gtkd_major}-%{sover}
Summary:        GtkD vted library
Group:          System/Libraries

%description -n libvted-%{gtkd_major}-%{sover}
This package contains the GtkD vted library.

%package     -n gtkd-devel
Summary:        GtkD devel and header files
Group:          Development/Languages/Other
Requires:       libgstreamerd-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkd-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkdgl-%{gtkd_major}-%{sover} = %{version}
Requires:       libgtkdsv-%{gtkd_major}-%{sover} = %{version}
Requires:       libpeasd-%{gtkd_major}-%{sover} = %{version}
Requires:       libvted-%{gtkd_major}-%{sover} = %{version}

%description -n gtkd-devel
This package contains the header files for GtkD a D binding and OO wrapper of GTK+

%prep
%autosetup -p1 -n GtkD-%{version}

sed -i 's|ldconfig|/sbin/ldconfig|g' GNUmakefile

%build
%make_build \
    DC=ldmd2 \
    CC=gcc libdir=%{?_lib} DCFLAGS='-O -release -inline -boundscheck=off -w -g' \
    shared-gstreamer \
    shared-gtkd \
    shared-gtkdgl \
    shared-peas \
    shared-sv \
    shared-vte

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{?_lib} \
    install-shared-gstreamer install-headers-gstreamer \
    install-shared-gtkd install-headers-gtkd \
    install-shared-gtkdgl install-headers-gtkdgl \
    install-shared-gtkdsv install-headers-gtkdsv \
    install-shared-peas install-headers-peas \
    install-shared-vte install-headers-vte

%post -n libgstreamerd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libgstreamerd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%post -n libgtkd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libgtkd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%post -n libgtkdgl-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libgtkdgl-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%post -n libgtkdsv-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libgtkdsv-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%post -n libpeasd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libpeasd-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%post -n libvted-%{gtkd_major}-%{sover} -p /sbin/ldconfig
%postun -n libvted-%{gtkd_major}-%{sover} -p /sbin/ldconfig

%files -n libgstreamerd-%{gtkd_major}-%{sover}
%{_libdir}/libgstreamerd-%{gtkd_major}.so.%{sover}
%{_libdir}/libgstreamerd-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files -n libgtkd-%{gtkd_major}-%{sover}
%{_libdir}/libgtkd-%{gtkd_major}.so.%{sover}
%{_libdir}/libgtkd-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files -n libgtkdgl-%{gtkd_major}-%{sover}
%{_libdir}/libgtkdgl-%{gtkd_major}.so.%{sover}
%{_libdir}/libgtkdgl-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files -n libgtkdsv-%{gtkd_major}-%{sover}
%{_libdir}/libgtkdsv-%{gtkd_major}.so.%{sover}
%{_libdir}/libgtkdsv-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files -n libpeasd-%{gtkd_major}-%{sover}
%{_libdir}/libpeasd-%{gtkd_major}.so.%{sover}
%{_libdir}/libpeasd-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files -n libvted-%{gtkd_major}-%{sover}
%{_libdir}/libvted-%{gtkd_major}.so.%{sover}
%{_libdir}/libvted-%{gtkd_major}.so.%{sover}.%{gtkd_minor}.%{gtkd_bugfix}

%files devel
%doc AUTHORS CHANGELOG README.md
%license COPYING
%dir %{_includedir}/d
%dir %{_includedir}/d/gtkd-%{gtkd_major}
%{_includedir}/d/gtkd-%{gtkd_major}/*
%{_libdir}/libgstreamerd-%{gtkd_major}.so
%{_libdir}/libgtkd-%{gtkd_major}.so
%{_libdir}/libgtkdgl-%{gtkd_major}.so
%{_libdir}/libgtkdsv-%{gtkd_major}.so
%{_libdir}/libpeasd-%{gtkd_major}.so
%{_libdir}/libvted-%{gtkd_major}.so
%{_libdir}/pkgconfig/*

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue Feb  9 2021 Matthias Eliasson <elimat@opensuse.org>
- use LDC for all architectures and for all openSUSE targets.
  LDC have better multiarch support and better to just maintain one d-compiler.
* Tue Aug 20 2019 Matthias Eliasson <elimat@opensuse.org>
- Add patch: fix-build.patch to fix pkgconfig files installing in correct path
* Tue Jun  4 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 3.9.0
- Use LDC for all architectures for Tumbleweed, LDC have better multiarch
  support and better we focous to support one d-compiler.
* Mon Jan  7 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 3.8.5
  * Set correct version during build
- Remove patch fix-correct-soname-version.patch, fixed upstream
* Sat Jan  5 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 3.8.4
  * Fix a memory leak when signals are used on a widget in a container. (gh#gtkd-developers/GtkD#254)
  * Update the GdkPixbuf Lookup file for the canges in 2.38. (gh#gtkd-developers/GtkD#250)
  * Add a get template for gobject.Value.
  * Don't hardcode pkg-config (gh#gtkd-developers/GtkD#249)
  * All function names and parameters that are D keywords are now post fixed with an underscore.
  * This is instead of the more random substitutes used previously.
  * Fix an out-of-bounds write in toStringzArray (gh#gtkd-developers/GtkD#248)
- Add patch fix-correct-soname-version.patch
- run spec-cleaner
* Thu Aug 30 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use LDC compiler when DMD is not available on architecture
* Sun Aug 19 2018 matthias.eliasson@gmail.com
- Update to version 3.8.3
  * Make sure we only use one toggle reference per GObject.
  * Allow empty arrays in the Dialog constructor.
  * Fix Windows build script. #242
* Tue May 22 2018 bjorn.lie@gmail.com
- Update to version 3.8.2:
  * Check for null in the ObjectG opCast, so we can cast objects
    that are null.
  * Add len and index methods to PtrArray.
- Changes from version 3.8.1:
  * Fix the gobject.Value constructor for Objects.
  * Also use toggle references for getInterfaceInstance.
- Changes from version 3.8.0:
  * Update the libraries to the latest versions.
  * Implement a DClosure.
  * Add a Signals.connect overload for D functions and delegates.
  * Bring back the OpCast changes for ObjectG.
  * Add ldc support to the Build.d script.
  * Clean up Idles and Timeouts when they are destroyed on the C
    side.
  * Add missing properties for gtk.TreeIter.
* Wed Mar 14 2018 matthias.eliasson@gmail.com
- Update to version 3.7.5
  * Check for null when returning an object in gtkd.Implement.
  * Handle out parameters correctly in gtkd.Implement.
  * Fix building with dmd 2.079.
- Change license to correct one and switch to SPDX-3.0 format.
* Wed Jan 24 2018 matthias.eliasson@gmail.com
- Added improved package descriptions.
* Tue Jan 23 2018 jengelh@inai.de
- Repair grammar in descriptions.
* Sun Jan 21 2018 matthias.eliasson@gmail.com
- Remove a faulty Requires for gtkd package in gtk-devel that does not exists.
* Mon Jan 15 2018 matthias.eliasson@gmail.com
- Remove unneccsery BuildRequires
- Add missing Requires
- Make sure this build on Leap
* Tue Jan  2 2018 matthias.eliasson@gmail.com
- Update to version 3.7.3
- Change from ldc to dmd as d compiler
- run spec-cleaner to clean up the spec
- add gstreamer, vte and peas bindings
- Add and rename shared-library sub-packages according to policy
  (https://en.opensuse.org/openSUSE:Shared_library_packaging_policy)
* Wed Dec 28 2016 jengelh@inai.de
- Rectify groups.
* Fri May  6 2016 mailaender@opensuse.org
- Update to version 3.3.1
* Fri Apr  1 2016 t.gruner@katodev.de
- Initial Version 3.3.0
